@@ -12,12 +12,12 @@ class AbstractAgent:
     def initialize(self):
         self.initializer.process(self.population)
 
-    def get_address(self):
-        return self.address
-
     def get_fitness(self):
         return max(genotype.fitness for genotype in self.population)
 
+    def get_best_genotype(self):
+        return max(self.population, key=lambda g: g.fitness)
+
     def add_genotype(self, population):
         logger.debug("received genotype!")
         self.population.extend(population)
@@ -42,7 +42,7 @@ class Agent(Addressable, AbstractAgent):
 
     def step(self):
         self.steps += 1
-        logger.debug("%s %s %s",self.steps, self.address, self.get_fitness())
+        logger.debug("%s %s %s", self.steps, self.address, self.get_fitness())
         for o in self.operators:
             o.process(self.population)
         self.__send_genotype()
@@ -54,7 +54,7 @@ class Agent(Addressable, AbstractAgent):
                 neighbour = self.locator.get_neighbour(self)
                 if neighbour:
                     logger.debug("neighbour: %s", neighbour.get_address())
-                    probe = list(self.population.sort(key=lambda g:g.fitness))[:20:2]
+                    probe = list(self.population.sort(key=lambda g: g.fitness))[:20:2]
                     neighbour.add_genotype(probe)
             except:
                 logging.exception('')
@@ -62,7 +62,6 @@ class Agent(Addressable, AbstractAgent):
     def __migrate(self):
         self.migration.migrate(self)
 
-
 class AggregateAgent(Addressable, AbstractAgent):
     @Inject("aggregated_agents:_AggregateAgent__agents")
     def __init__(self, name=None):
@@ -92,6 +91,9 @@ class AggregateAgent(Addressable, AbstractAgent):
     def get_fitness(self):
         return max(agent.get_fitness() for agent in self.__agents.values())
 
+    def get_best_genotype(self):
+        return max(self.__agents.values(), key=lambda a: a.get_fitness()).get_best_genotype()
+
 
 def agents_factory(*args):
     def factory():
