@@ -1,9 +1,10 @@
-import random
+from random import uniform
+from pyage.core.emas import EmasAgent
 from pyage.core.operator import Operator
 from pyage.solutions.evolution.genotype import PointGenotype
 
 class PointInitializer(Operator):
-    def __init__(self, size=100, lowerbound = 0.0, upperbound = 1.0):
+    def __init__(self, size=100, lowerbound=0.0, upperbound=1.0):
         super(PointInitializer, self).__init__(PointGenotype)
         self.size = size
         self.lowerbound = lowerbound
@@ -14,5 +15,13 @@ class PointInitializer(Operator):
             population.append(PointGenotype(self.__randomize(), self.__randomize()))
 
     def __randomize(self):
-        return random.uniform(self.lowerbound, self.upperbound)
+        return uniform(self.lowerbound, self.upperbound)
+
+
+def emas_initializer(energy=10, size=100, lowerbound=0.0, upperbound=1.0):
+    agents = {}
+    for i in range(size):
+        agent = EmasAgent(PointGenotype(uniform(lowerbound, upperbound), uniform(lowerbound, upperbound)), energy)
+        agents[agent.get_address()] = agent
+    return agents
 
